.. _run:

Developmental Guide
=====================================

.. module:: gseapy


Module APIs
---------------------


.. autofunction:: gsea()


.. autofunction:: prerank()

.. autofunction:: ssgsea()


.. autofunction:: enrichr()

.. autofunction:: replot()


Algorithm
-------------------------


.. automodule:: gseapy.algorithm
   :members:


Enrichr
--------------------------

.. automodule:: gseapy.enrichr
   :members:


Parser
--------------------------

.. automodule:: gseapy.parser
   :members:


Graph
--------------------------

.. automodule:: gseapy.plot
   :members:
